==> dde-control-center_6.1.22.tar.xz: BUILD/translations/keyboard_language_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Afrikaans</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>አማርኛ</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>عربية</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>অসমীয়া</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturijski</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Bjeloruski</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Български</source>
        <translation>Bugarski</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bosanski</translation>
    </message>
    <message>
        <source>Català</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Český</source>
        <translation>Češki</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Danski</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Njemački</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Grčki</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>Britanski engleski</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>Američki engleski</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Španjolski</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Estonski</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Baskijski</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Finski</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Français</source>
        <translation>Francuski</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Galješki</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Galego</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gaelg</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>עברית</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Hrvatski</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Mađarski</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonezijski</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Íslenska</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Talijanski</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>日本語</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ქართული</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Қазақша</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>한국어</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>Kurdski</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Limburgs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ລາວ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Litvanski</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Latvijski</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Malagasy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ebon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Māori</source>
        <translation>Maorski</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Makedonski</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Mongolski</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Malti</source>
        <translation>Malteški</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Norveški (bokmål)</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>नेपाली</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Nizozemski</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Norveški (nynorsk)</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Occitan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Oromoo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Иронау</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Polski</source>
        <translation>Poljski</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Português</source>
        <translation>Poetugalski</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Brazilski portugalski</translation>
    </message>
    <message>
        <source>Română</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Русский</source>
        <translation>Ruski</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sardu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>سنڌي</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>සිංහල</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Slovenski</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Slovenski</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Albanski</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Srpski</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>srpski (latinica)</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sesotho</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Švedski</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Turkmenistanski</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Turski</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Tatarski</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Українська</source>
        <translation>Ukrajinski</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbečki (ćirilica)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Walon</source>
        <translation>Valonski</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>isixhosa</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>简体中文</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>繁體中文(中國香港)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>繁體中文</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>isiZulu</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-control-center_6.1.27.tar.xz: BUILD/translations/keyboard_language_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Afrikaans</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>አማርኛ</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>عربية</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>অসমীয়া</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturijski</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Bjeloruski</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Bugarski</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bosanski</translation>
    </message>
    <message>
        <source>Català</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Češki</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Danski</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Njemački</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Grčki</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>Britanski engleski</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>Američki engleski</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Španjolski</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Estonski</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Baskijski</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Finski</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Français</source>
        <translation>Francuski</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Galješki</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Galego</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>עברית</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Hrvatski</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Mađarski</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonezijski</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Talijanski</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>日本語</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>한국어</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>Kurdski</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Litvanski</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Latvijski</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Maorski</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Makedonski</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Mongolski</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Malteški</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Norveški (bokmål)</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Nizozemski</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Norveški (nynorsk)</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Poljski</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Poetugalski</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Brazilski portugalski</translation>
    </message>
    <message>
        <source>Română</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Ruski</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Slovenski</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Slovenski</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Albanski</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Srpski</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>srpski (latinica)</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Švedski</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Turkmenistanski</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Turski</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Tatarski</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Ukrajinski</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbečki (ćirilica)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Valonski</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>繁體中文(中國香港)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>繁體中文</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Català (Valencià)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Esperanto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interlingua</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kabyle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Azerbaijani</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filipino</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
